##  Activating the System Fact Sheet
The system fact sheet is an optional fact sheet type. To add it to your meta model, do the following:
  1. Navigate to the Optional Features & Early Access section in the administration area.
  2. Click Review and Activate next to System Fact Sheet.
  3. In the resulting outlay, click Activate Extension.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe9d04716b248459b9d1e85786937d485_LowRes.png)
Activating the System Fact Sheet
**Note**
  * Once the system fact sheet is activated, it cannot be automatically rolled back and can only be removed manually in the meta model configuration.
  * You can also activate the system fact sheet while configuring SAP discovery. For more details, see [Step 3: Connect SAP LeanIX to SAP Cloud ALM](https://help.sap.com/docs/leanix/ea/sap-discovery-configuring-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759721b7a441014bd508464cc06d9fa__Step-3_-Connect-SAP-LeanIX-to-SAP-Cloud-ALM).
